/*
 * < KURA, This application manages the daily activities of a Teacher and a Student of a School>
 *
 * Copyright (C) 2012 Virtusa Corporation.
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

USE `akura`;

--
-- Remove sorting function from the student scholarship view.
--

CREATE  OR REPLACE VIEW STUDENTSCHOLARSHIPVIEW AS
	SELECT `shlor`.`NAME` AS `scholarshipName`,`stu`.`ADMISSION_NO` AS `admissionNo`,`stu`.`NAME_WT_INITIALS` AS `nameWithInitials`,`cg`.`DESCRIPTION` AS `description` 
	FROM ((((`STUDENT_SCHOLARSHIP` `sh` join `STUDENT` `stu`) JOIN `SCHOLARSHIP` `shlor`) JOIN `STUDENT_CLASS_INFO` `stuInfo`) JOIN `CLASS_GRADE` `cg`)
	WHERE ((`shlor`.`SCHOLARSHIP_ID` = `sh`.`SCHOLARSHIP_ID`)
		AND (`stu`.`STUDENT_ID` = `sh`.`STUDENT_ID`)
		AND (`sh`.`STUDENT_ID` = `stuInfo`.`STUDENT_ID`) 
		AND (`cg`.`CLASS_GRADE_ID` = `stuInfo`.`CLASS_GRADE_ID`)
		AND (`sh`.`YEAR` = `stuInfo`.`YEAR`));
		
--
-- alter view to be used only for completed marks records.
-- added name with initial column.
--

CREATE OR REPLACE VIEW ABSENTEE_LIST_VIEW AS 
SELECT 
STUDENT_TERM_MARK.STUDENT_TERM_MARKS_ID AS STUDENT_TERM_MARKS_ID, 
STUDENT.NATIONALITY_ID AS NATIONALITY_ID, 
STUDENT.FULL_NAME AS FULL_NAME , 
STUDENT.NAME_WT_INITIALS AS NAME_WITH_INITIALS,
STUDENT.ADMISSION_NO AS ADMISSION_NO, 
CLASS_GRADE.DESCRIPTION AS CLASS_DESCRIPTION, 
GRADE.DESCRIPTION AS GRADE_DESCRIPTION , 
TERM.DESCRIPTION AS TERM_DESCRIPTION , 
SUBJECT.DESCRIPTION AS SUBJECT_DESCRIPTION , 
STUDENT_TERM_MARK.MARKS AS MARKS, 
STUDENT_TERM_MARK.IS_ABSENT AS IS_ABSENT,
MARKING_FLAG.MARKING_COMPLETED AS MARKING_COMPLETED

FROM STUDENT_TERM_MARK

LEFT JOIN STUDENT_CLASS_INFO
ON STUDENT_TERM_MARK.STUDENT_CLASS_INFO_ID = STUDENT_CLASS_INFO.STUDENT_CLASS_INFO_ID

LEFT JOIN STUDENT
ON STUDENT_CLASS_INFO.STUDENT_ID = STUDENT.STUDENT_ID

LEFT JOIN CLASS_GRADE
ON STUDENT_CLASS_INFO.CLASS_GRADE_ID = CLASS_GRADE.CLASS_GRADE_ID 

LEFT JOIN MARKING_FLAG
ON (CLASS_GRADE.CLASS_GRADE_ID = MARKING_FLAG.CLASS_GRADE_ID AND MARKING_FLAG.MARKING_COMPLETED = TRUE)

LEFT JOIN CLASS
ON CLASS_GRADE.CLASS_ID = CLASS.CLASS_ID

LEFT JOIN GRADE
ON CLASS_GRADE.GRADE_ID = GRADE.GRADE_ID

LEFT JOIN GRADE_SUBJECT
ON STUDENT_TERM_MARK.GRADE_SUBJECT_ID = GRADE_SUBJECT.GRADE_SUBJECT_ID


LEFT JOIN SUBJECT
ON GRADE_SUBJECT.SUBJECT_ID = SUBJECT.SUBJECT_ID

LEFT JOIN TERM
ON (STUDENT_TERM_MARK.TERM_ID = TERM.TERM_ID AND MARKING_FLAG.TERM_ID=TERM.TERM_ID)

WHERE TERM.DESCRIPTION IS NOT NULL

ORDER BY STUDENT.FULL_NAME,TERM.DESCRIPTION;

--
-- STUDENT_DISCIPLINE_VIEW 
-- Purpose of this view is to show the student discipline .  
-- ALTER VIEW for adding name with initials.
--  
    
CREATE OR REPLACE VIEW STUDENT_DISCIPLINE_VIEW AS
SELECT
sd.STUDENT_DISCIPLINE_ID AS STUDENT_DISCIPLINE_ID,
sd.STUDENT_ID AS STUDENT_ID,
s.ADMISSION_NO AS ADMISSION_NO, 
s.FULL_NAME AS FULL_NAME, 
s.NAME_WT_INITIALS AS NAME_WITH_INITIALS,
sd.date AS WARN_DATE , 
sd.COMMENT AS WARNING,
wl.DESCRIPTION  AS WARNING_LEVEL, 
ul.FIRST_NAME AS TEACHER_NAME,
sd.IS_INFORMED_TO_PARENT AS INFORMED_TO_PARENT,
cg.DESCRIPTION AS CLASS_DESCRIPTION

FROM STUDENT_DISCIPLINE sd
LEFT JOIN WARNING_LEVEL wl
ON  sd.WARNING_LEVEL_ID  = wl.WARNING_LEVEL_ID

LEFT JOIN STUDENT s
ON  sd.STUDENT_ID =s.STUDENT_ID

LEFT JOIN USER_LOGIN ul
ON sd.USER_LOGIN_ID = ul.USER_LOGIN_ID 

LEFT JOIN STUDENT_CLASS_INFO sci
ON s.STUDENT_ID = sci.STUDENT_ID

LEFT JOIN CLASS_GRADE cg
ON sci.CLASS_GRADE_ID = cg.CLASS_GRADE_ID

LEFT JOIN CLASS c
ON cg.CLASS_ID = c.CLASS_ID

LEFT JOIN GRADE g
ON cg.GRADE_ID = g.GRADE_ID

WHERE YEAR(sd.date) = YEAR(sci.year) AND YEAR(sci.year) = year(now());	

--
-- EXAM_RESULTS_VIEW
-- Purpose of this view is to generate student's Exam Results
-- alter view for adding name with initials.
--

CREATE OR REPLACE VIEW  EXAM_RESULTS_VIEW
AS
SELECT 
s.STUDENT_ID, 
s.FULL_NAME, 
s.NAME_WT_INITIALS AS NAME_WITH_INITIALS,
sub.DESCRIPTION as SUB_DESCRIPTION, 
em.YEAR, em.MARKS, 
g.GRADE_ACRONYM,
g.DESCRIPTION as GRADING_DESCRIPTION, 
e.EXAM_ID, 
e.DESCRIPTION as EXAM_DESCRIPTION,
e.MARK_TYPE, 
es.IS_OPTIONAL_SUBJECT, 
ea.ADMISSION_NO,
em.IS_ABSENT AS ABSENT,
em.IS_OPTIONAL AS OPTIONAL

FROM EXAM_MARKS em 

LEFT JOIN EXAM_SUBJECT es ON em.EXAM_SUBJECT_ID=es.EXAM_SUBJECT_ID 
LEFT JOIN GRADING g on em.GRADING_ID=g.GRADING_ID 
LEFT JOIN STUDENT s ON em.STUDENT_ID=s.STUDENT_ID 
LEFT JOIN EXAM e ON es.EXAM_ID=e.EXAM_ID 
LEFT JOIN SUBJECT sub ON es.SUBJECT_ID=sub.SUBJECT_ID , EXAM_ADMISSIONS ea

WHERE ea.EXAM_ID=e.EXAM_ID AND em.YEAR=ea.YEAR AND em.STUDENT_ID=ea.STUDENT_ID 
AND 
(es.IS_OPTIONAL_SUBJECT = 0 OR em.MARKS is not null OR em.GRADING_ID is not null 
OR em.IS_ABSENT = 1 
OR (em.IS_ABSENT = 0 AND em.MARKS is not null AND em.GRADING_ID is not null));

     
      
