# create database school;

# use school;

#
# Table school
# Keeps information about school
#

drop table if exists school;

create table school(
feature      varchar(10) not null primary key,
fdesc        varchar(100));

insert into school values('sname', 'Sample School');
insert into school values('sadd', 'New Delhi, India');
insert into school values('sphone', '');

################################################################################
#
#
#                            Login System
#
#
################################################################################


#
# Table person
# keeps general record of every user
#

drop table if exists person;

create table person(
uid      varchar(30) not null,
primary key (uid),
pname    varchar(30),
fname    varchar(30),
mname    varchar(30),
dob      date,
sex      enum('M','F'),
hno      varchar(10),
street   varchar(20),
city     varchar(20),
pcode    integer(6));

insert into person(uid,pname) values('satya','System Administrator');

# 
# Table stud
# Maintains records specific to a student
#

drop table if exists stud;
create table stud(
enrolno   integer(6) auto_increment not null,
primary key (enrolno),
uid       varchar(30) references person(person_id),
gid       varchar(30),
doadm       date,
clsofadm    integer(2),
secofadm    char(1),
currcls     integer(2),
currsec     char(1),
doexit      date,
reason      varchar(50),
clsofexit   integer(2),
secofexit   char(1),
comment     varchar(50));

#
# View student
# Unifies all the records of a student
#

drop view if exists student;

create view student as select enrolno, pname sname, fname,mname,gid,dob,doadm,sex,hno,street,city,pcode,clsofadm,secofadm,currcls,currsec,doexit,reason,clsofexit,secofexit,comment from person, stud where person.uid=stud.uid;

#
# Table designation
# Keeps details of designations
#

drop table if exists designation;

create table designation(
did       integer not null auto_increment,
primary key (did),
dname     varchar(20));


insert into designation values(1000, 'System Administrator');
insert into designation values(1001, 'Principal');
insert into designation values(1002, 'Teacher');

#
# Table emp
# Keeps records specific to an employee
#

drop table if exists emp;

create table emp(
empid     integer not null primary key auto_increment,
uid       varchar(30) references person(uid),
did       integer references designation(did),
doj       date not null,
edu       varchar(40),
email     varchar(30),
phone     varchar(15),
bankac    varchar(10),
basic     decimal(8,2),
hra       decimal(8,2),
dall      decimal(5,2),
cityall   decimal(6,2),
otherall  decimal(7,2),
oalldsc   varchar(50),
pfund     decimal(6,2),
pfno      varchar(10),
othercuts decimal(6,2),
ocutsdsc  varchar(50));

insert into emp(empid, uid, did, doj) values(10000,'satya',1000,curdate());

#
# View employee
# Unifies all the records pertaining to an employee
#

drop view if exists employee;
create view employee as select empid,pname empname, did, fname,mname,dob,doj,sex,edu,hno,street,city,pcode,email,phone,bankac,basic,hra,dall,cityall,otherall,oalldsc,pfund,pfno,othercuts,ocutsdsc from person,emp where person.uid=emp.uid;


#
# Table users
# Keeps userids and passwords
#

drop table if exists users;

create table users(
uname           varchar(30) not null primary key,
passwd          blob);

insert into users values('satya',aes_encrypt('prakash','prakash'));


####################################################################
#
#                       Rights Management
#
####################################################################


#
# Table rght
# Gives details of various rights
#

drop table if exists rght;

create table rght(
rightid    varchar(10) not null primary key,
rname      varchar(50),
rlink      varchar(100));


insert into rght values('adm', 'Admission','pre-admission.php');
insert into rght values('admauth', 'Admission Authorisation','admauth.php');
insert into rght values('addemp','Add Employee','personentry.php?utype=emp');
insert into rght values('adddesig', 'Add Designation','add-desig.php');
insert into rght values('addcls', 'Add Class','addclasses.php');
insert into rght values('addsub', 'Add Subject','add-sub.php');
insert into rght values('roledef', 'Role Define','');
insert into rght values('roleassig', 'Role Assign','');
insert into rght values('comm', 'Comment','');
insert into rght values('ucreate', 'Create User','create-user.php');


#
# Table role
# Specifies various roles to be assigned to users
#

drop table if exists role;

create table role(
roleid     varchar(10) not null primary key,
rolename   varchar(50));


insert into role values('emp', 'Employee');
insert into role values('head', 'Head of Institution');
insert into role values('sysadmin', 'System Administrator');
insert into role values('adminc', 'Admission Incharge');

#
# Table rolerght
# Defines rights of each role
#

drop table if exists rolerght;

create table rolerght(
roleid     varchar(10) references role(roleid),
rightid    varchar(10) references rght(rightid));


insert into rolerght values('emp', 'comm');
insert into rolerght values('head', 'adm');
insert into rolerght values('head', 'admauth');
insert into rolerght values('head', 'addemp');
insert into rolerght values('head', 'adddesig');
insert into rolerght values('head', 'addcls');
insert into rolerght values('head', 'addsub');
insert into rolerght values('head', 'roledef');
insert into rolerght values('head', 'roleassig');
insert into rolerght values('head', 'comm');
insert into rolerght values('sysadmin', 'addemp');
insert into rolerght values('sysadmin', 'adddesig');
insert into rolerght values('sysadmin', 'addcls');
insert into rolerght values('sysadmin', 'addsub');
insert into rolerght values('sysadmin', 'roledef');
insert into rolerght values('sysadmin', 'roleassig');
insert into rolerght values('sysadmin', 'ucreate');
insert into rolerght values('adminc', 'adm');

#
# Table assign
# Keeps track or roles assigned to users
#

drop table if exists assign;
create table assign(
assignid     integer not null primary key auto_increment,
roleid       varchar(10) references role(roleid),
assignto     varchar(30) references users(uname),
dateofassign date,
assignby     integer references employee(empid));

insert into assign values(10000, 'sysadmin', 'satya', curdate(), 'satya');
insert into assign values(null, 'head', 'satya', curdate(), 'satya');

#
# Table status
# Presently redundant
#

drop table if exists status;

create table status(
statid       integer not null primary key auto_increment,
statname     varchar(20));

#
# Table admission
# Keeps record of initial unapproved admission
#

drop table if exists admission;

create table admission(
admid        integer not null auto_increment,
primary key (admid),
uid			 varchar(30),
gid			 varchar(30),
doadm        date,
clsofadm     integer(2),
secofadm     char(1),
statid       integer references status(statid),
reasonofrej  varchar(100));

#
# Table classes
# Keeps records of classes and sections
#

drop table if exists classes;

create table classes(
cls        integer(2) not null,
section      char(1) not null,
primary key  (cls,section),
teacherid    integer references employee(empid));

#
# Table teachercomm
# Keeps record of comments given by teacher
#

drop table if exists teachercomm;

create table teachercomm(
commid         integer not null primary key auto_increment,
teacherid      integer references employee(empid),
enrolno        integer(6) references student(enrolno),
comment        text,
replyof        integer);

#
# Table subjects
# Keeps record of various subjects
#

drop table if exists subjects;

create table subjects(
subid          integer not null primary key auto_increment,
subname	       varchar(30));

#
# Table subteacher
# Keeps track of teachers of a particular subject
#

drop table if exists subteacher;

create table subteacher(
cls             integer(2) references classes(class),
section         char(1) references classes(section),
subid           integer references subjects(subid),
teacherid       integer references employee(empid));



